@@ -15,19 +15,23 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: PageInfoPrivate.cpp,v 1.1 2005/02/11 15:44:02 chpe Exp $
+ *  $Id: PageInfoPrivate.cpp,v 1.2 2006/05/10 18:14:59 chpe Exp $
  */
 
 #include "mozilla-config.h"
-
 #include "config.h"
 
-#include "PageInfoPrivate.h"
+#include <nscore.h>
+
+#define MOZILLA_INTERNAL_API 1
+#include <nsString.h>
 
 #include <nsCOMPtr.h>
 #include <nsIDOMDocument.h>
 #include <nsIHTMLDocument.h>
 
+#include "PageInfoPrivate.h"
+
 EmbedPageRenderMode
 PageInfoPrivate::GetRenderMode (nsIDOMDocument *aDocument)
 {
